==> haskell-expiring-cache-map-0.0.6.1-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-AwpDZ0FBNST5b8m0QQ2AAQ
key:                  expiring-cache-map-0.0.6.1-AwpDZ0FBNST5b8m0QQ2AAQ
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  344911ca01970a1d0c9b34db2d1acf3c
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/expiring-cache-map-0.0.6.1

hs-libraries:         HSexpiring-cache-map-0.0.6.1-AwpDZ0FBNST5b8m0QQ2AAQ
depends:
    base-4.15.0.0 containers-0.6.4.1
    hashable-1.3.4.0-6dnecuFViZBGFpHQwXe7GH
    unordered-containers-0.2.14.0-FVdmWuNRiZiBPBGw5WvZRu

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-181-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-Ewo2W8pR5N2AsjfD8aHirL
key:                  expiring-cache-map-0.0.6.1-Ewo2W8pR5N2AsjfD8aHirL
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  c9162cfc8c16427c9d987beeae8aa930
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/expiring-cache-map-0.0.6.1

hs-libraries:         HSexpiring-cache-map-0.0.6.1-Ewo2W8pR5N2AsjfD8aHirL
depends:
    base-4.15.0.0 containers-0.6.4.1
    hashable-1.3.4.0-IEtvls2JnYMCj5AtMjw8bF
    unordered-containers-0.2.14.0-7Twq3Q78XsnAV2eREMKYwX

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
